"""
Copyright (c) 2010-present by Jaxl Innovations Private Limited.

All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, is strictly prohibited.
"""

from typing import (
    TYPE_CHECKING,
    Any,
    Dict,
    List,
    Optional,
    Type,
    TypeVar,
    Union,
)

import attr

from ..types import UNSET, Unset


if TYPE_CHECKING:
    from ..models.campaign_metadata_metadata import CampaignMetadataMetadata


T = TypeVar("T", bound="CampaignMetadata")


@attr.s(auto_attribs=True)
class CampaignMetadata:
    """
    Attributes:
        metadata (Union[Unset, None, CampaignMetadataMetadata]): Any additional metadata provided with target
        name (Optional[str]):
    """

    name: Optional[str]
    metadata: Union[Unset, None, "CampaignMetadataMetadata"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        metadata: Union[Unset, None, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict() if self.metadata else None

        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
            }
        )
        if metadata is not UNSET:
            field_dict["metadata"] = metadata

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.campaign_metadata_metadata import (
            CampaignMetadataMetadata,
        )

        d = src_dict.copy()
        _metadata = d.pop("metadata", UNSET)
        metadata: Union[Unset, None, CampaignMetadataMetadata]
        if _metadata is None:
            metadata = None
        elif isinstance(_metadata, Unset):
            metadata = UNSET
        else:
            metadata = CampaignMetadataMetadata.from_dict(_metadata)

        name = d.pop("name")

        campaign_metadata = cls(
            metadata=metadata,
            name=name,
        )

        campaign_metadata.additional_properties = d
        return campaign_metadata

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
